@@ -5,6 +5,7 @@ Uses QuantumESPRESSO pw.x and xspectra.x, requires ``aiida-shell`` to run ``upf2
 """
 import pathlib
 from typing import Optional, Union
+import warnings
 
 from aiida import orm
 from aiida.common import AttributeDict
@@ -13,16 +14,24 @@ from aiida.orm.nodes.data.base import to_aiida_type
 from aiida.plugins import CalculationFactory, DataFactory, WorkflowFactory
 import yaml
 
-from aiida_quantumespresso.calculations.functions.xspectra.get_powder_spectrum import get_powder_spectrum
-from aiida_quantumespresso.calculations.functions.xspectra.merge_spectra import merge_spectra
 from aiida_quantumespresso.utils.mapping import prepare_process_inputs
 from aiida_quantumespresso.workflows.protocols.utils import ProtocolMixin, recursive_merge
 
 PwCalculation = CalculationFactory('quantumespresso.pw')
 PwBaseWorkChain = WorkflowFactory('quantumespresso.pw.base')
-XspectraBaseWorkChain = WorkflowFactory('quantumespresso.xspectra.base')
+with warnings.catch_warnings():
+    warnings.simplefilter('ignore')
+    from aiida_quantumespresso.calculations.functions.xspectra.get_powder_spectrum import get_powder_spectrum
+    from aiida_quantumespresso.calculations.functions.xspectra.merge_spectra import merge_spectra
+    XspectraBaseWorkChain = WorkflowFactory('quantumespresso.xspectra.base')
+
 HubbardStructureData = DataFactory('quantumespresso.hubbard_structure')
 
+warnings.warn(
+    'This module is deprecated and will be removed soon as part of migrating XAS and XPS workflows to a new repository.'
+    '\nThe new repository can be found at: https://github.com/aiidaplugins/aiida-qe-xspec.', FutureWarning
+)
+
 
 class XspectraCoreWorkChain(ProtocolMixin, WorkChain):
     """Workchain to compute X-ray absorption spectra for a given structure using Quantum ESPRESSO.
